@@ -247,7 +247,7 @@ def version_options(function: typ.Callable) -> typ.Callable:
 
 
 @click.group()
-@click.version_option(version="2021.1113")
+@click.version_option(version="2021.1114")
 @click.help_option()
 @verbose_option
 def cli(verbose: int = 0) -> None:
@@ -677,6 +677,32 @@ def _update_cfg_from_vcs(cfg: config.Config, fetch: bool) -> config.Config:
             )
 
 
+def _parse_vcs_options(
+    cfg       : config.Config,
+    commit    : typ.Optional[bool] = None,
+    tag_commit: typ.Optional[bool] = None,
+    push      : typ.Optional[bool] = None,
+) -> config.Config:
+    if commit is False and tag_commit:
+        raise ValueError("--no-commit and --tag-commit cannot be used at the same time")
+    if commit is False and push:
+        raise ValueError("--no-commit and --push cannot be used at the same time")
+
+    if commit is not None:
+        cfg = cfg._replace(commit=commit)
+
+    if not cfg.commit and tag_commit:
+        raise ValueError("--tag-commit requires either --commit or commit=True in your config")
+    if not cfg.commit and push:
+        raise ValueError("--push requires either --commit or commit=True in your config")
+
+    if tag_commit is not None:
+        cfg = cfg._replace(tag=tag_commit)
+    if push is not None:
+        cfg = cfg._replace(push=push)
+    return cfg
+
+
 @cli.command()
 @dry_option
 @fetch_option
@@ -699,6 +725,21 @@ def _update_cfg_from_vcs(cfg: config.Config, fetch: bool) -> config.Config:
     metavar="<TMPL>",
     help="Set commit message template.",
 )
+@click.option(
+    "--commit/--no-commit",
+    default=None,
+    help="Create a commit with all updated files.",
+)
+@click.option(
+    "--tag-commit/--no-tag-commit",
+    default=None,
+    help="Tag the newly created commit.",
+)
+@click.option(
+    "--push/--no-push",
+    default=None,
+    help="Push to the default remote.",
+)
 def update(
     dry           : bool = False,
     allow_dirty   : bool = False,
@@ -713,6 +754,9 @@ def update(
     date          : typ.Optional[str] = None,
     set_version   : typ.Optional[str] = None,
     commit_message: typ.Optional[str] = None,
+    commit        : typ.Optional[bool] = None,
+    tag_commit    : typ.Optional[bool] = None,
+    push          : typ.Optional[bool] = None,
 ) -> None:
     """Update project files with the incremented version string."""
     verbose = max(_VERBOSE, verbose)
@@ -726,6 +770,12 @@ def update(
         logger.error("Could not parse configuration.")
         sys.exit(1)
 
+    try:
+        cfg = _parse_vcs_options(cfg, commit, tag_commit, push)
+    except ValueError as ex:
+        logger.warning(f"Invalid argument: {ex}")
+        sys.exit(1)
+
     cfg = _update_cfg_from_vcs(cfg, fetch)
 
     old_version = cfg.current_version
